@@ -2,13 +2,25 @@
  * This file is part of the Score-P software (http://www.score-p.org)
  *
  * Copyright (c) 2009-2011,
- *    RWTH Aachen University, Germany
- *    Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
- *    Technische Universitaet Dresden, Germany
- *    University of Oregon, Eugene, USA
- *    Forschungszentrum Juelich GmbH, Germany
- *    German Research School for Simulation Sciences GmbH, Juelich/Aachen, Germany
- *    Technische Universitaet Muenchen, Germany
+ * RWTH Aachen University, Germany
+ *
+ * Copyright (c) 2009-2011,
+ * Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
+ *
+ * Copyright (c) 2009-2011, 2019,
+ * Technische Universitaet Dresden, Germany
+ *
+ * Copyright (c) 2009-2011,
+ * University of Oregon, Eugene, USA
+ *
+ * Copyright (c) 2009-2011,
+ * Forschungszentrum Juelich GmbH, Germany
+ *
+ * Copyright (c) 2009-2011,
+ * German Research School for Simulation Sciences GmbH, Juelich/Aachen, Germany
+ *
+ * Copyright (c) 2009-2011,
+ * Technische Universitaet Muenchen, Germany
  *
  * See the COPYING file in the package base directory for details.
  *
@@ -139,14 +151,16 @@ main( int    argc,
         {
             action = ACTION_POMP2_API_VERSION;
         }
-        else if ( strcmp( argv[ i ], "--opari2-revision" ) == 0 )
+        else if ( strcmp( argv[ i ], "--revision" ) == 0 )
         {
             std::cout << SCOREP_COMPONENT_REVISION << std::endl;
             exit( EXIT_SUCCESS );
         }
-        else if ( strcmp( argv[ i ], "--common-revision" ) == 0 )
+        else if ( strcmp( argv[ i ], "--opari2-revision" ) == 0 ||
+                  strcmp( argv[ i ], "--common-revision" ) == 0 )
         {
-            std::cout << SCOREP_COMMON_REVISION << std::endl;
+            std::cerr << "[OPARI2] warning: " << argv[ i ] << " is deprecated" << std::endl;
+            std::cout << SCOREP_COMPONENT_REVISION << std::endl;
             exit( EXIT_SUCCESS );
         }
         else if ( strncmp( argv[ i ], "--config", 8 ) == 0 )
